from django.apps import AppConfig


class B2UtilsConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "b2_utils"
